@@ -4,10 +4,12 @@ import geopandas
 from polygon_geohasher.polygon_geohasher import geohashes_to_polygon
 import json
 
-def geohash_to_geojson(geohashes):
+def geohash_to_geojson(geohashes=['snd1j0']):
 	geojson = []
 	for i in range(0,len(geohashes)):
 		geojson.append(geopandas.GeoSeries([geohashes_to_polygon([geohashes[i]])]).to_json())
+    
+    geojson[0]['features'][0]['properties']['id']=geohashes[0]
 	d = json.loads(geojson[0])
 	for i in range(1,len(geojson)):
 		data=json.loads(geojson[i])
